@@ -225,8 +225,10 @@ class AndroidPatcher(BasePlatformPatcher):
             '-version',
         ]), timeout=self.command_run_timeout).out.strip()
 
-        # windows / delegator weirdness...
-        if 'Press any key to continue . . .' in o:
+        # On windows we get this 'Press any key to continue' thing,
+        # localized to the the current language. Assume that the version
+        # string we want is always the first line.
+        if len(o.split('\n')) > 1:
             o = o.split('\n')[0]
 
         if len(o) == 0:
